@@ -1,8 +1,8 @@
 package BalanceOfPower::Commands;
-$BalanceOfPower::Commands::VERSION = '0.300012';
+$BalanceOfPower::Commands::VERSION = '0.300020';
 use v5.10;
 use Moo;
-use IO::Prompter;
+use IO::Prompter [-stdio];
 use Term::ANSIColor;
 use BalanceOfPower::Player;
 use BalanceOfPower::Executive;
