@@ -1,5 +1,5 @@
 package BalanceOfPower::Nation;
-$BalanceOfPower::Nation::VERSION = '0.300012';
+$BalanceOfPower::Nation::VERSION = '0.300020';
 use strict;
 use v5.10;
 
@@ -282,7 +282,9 @@ sub lower_disorder
     {
         $self->subtract_production('domestic', RESOURCES_FOR_DISORDER);
         $self->add_internal_disorder(-1 * DISORDER_REDUCTION, $world);
-        $self->register_event("DISORDER LOWERED TO " . $self->internal_disorder);
+        $world->broadcast_event({ code => 'lowerdisorder',
+                                  text => "DISORDER LOWERED TO " . $self->internal_disorder. " IN " . $self->name,
+                                  involved => [$self->name] }, $self->name);
     }
 }
 
@@ -306,7 +308,9 @@ sub add_internal_disorder
     my $new_disorder = $self->internal_disorder_status;
     if($actual_disorder ne $new_disorder)
     {
-        $self->register_event("INTERNAL DISORDER LEVEL FROM $actual_disorder TO $new_disorder");
+        $world->broadcast_event({ code => 'disorderchange',
+                                  text => "INTERNAL DISORDER LEVEL FROM $actual_disorder TO $new_disorder IN " . $self->name,
+                                  involved => [$self->name] }, $self->name);
         if($new_disorder eq "Civil war")
         {
             $world->start_civil_war($self);
@@ -365,25 +369,23 @@ sub fight_civil_war
     }
     if($reb_sup)
     {
-        $world->broadcast_event("RELATIONS BETWEEN " . $self->name . " AND " . $reb_sup->node1 . " CHANGED FOR CIVIL WAR IN " . $self->name, $self->name, $reb_sup->node1);
-        $world->change_diplomacy($self->name, $reb_sup->node1, -1 * DIPLOMACY_MALUS_FOR_REBEL_CIVIL_WAR_SUPPORT);
+        $world->change_diplomacy($self->name, $reb_sup->node1, -1 * DIPLOMACY_MALUS_FOR_REBEL_CIVIL_WAR_SUPPORT, "CIVIL WAR IN " . $self->name);
     }
     if($sup && $reb_sup)
     {
-        $world->broadcast_event("RELATIONS BETWEEN " . $sup->node1 . " AND " . $reb_sup->node1 . " CHANGED FOR CIVIL WAR IN " . $self->name, $self->name, $sup->node1, $reb_sup->node1);
-        $world->change_diplomacy($sup->node1, $reb_sup->node1, -1 * DIPLOMACY_MALUS_FOR_CROSSED_CIVIL_WAR_SUPPORT);
+        $world->change_diplomacy($sup->node1, $reb_sup->node1, -1 * DIPLOMACY_MALUS_FOR_CROSSED_CIVIL_WAR_SUPPORT, "CIVIL WAR IN " . $self->name);
     }
     if($government > $rebels)
     {
         $reb_sup->casualities(1) if $reb_sup;
         $world->rebel_military_support_garbage_collector();
-        return $self->civil_war_battle('government');
+        return $self->civil_war_battle('government', $world);
     }
     elsif($rebels > $government)
     {
         $sup->casualities(1) if $sup;
         $world->military_support_garbage_collector();
-        return $self->civil_war_battle('rebels');
+        return $self->civil_war_battle('rebels', $world);
     }
     else
     {
@@ -395,6 +397,7 @@ sub civil_war_battle
 {
     my $self = shift;
     my $battle_winner = shift;
+    my $world = shift;
     if($battle_winner eq 'government')
     {
         $self->rebel_provinces($self->rebel_provinces() - .5);
@@ -406,13 +409,18 @@ sub civil_war_battle
     if($self->rebel_provinces == 0)
     {
         $self->internal_disorder(AFTER_CIVIL_WAR_INTERNAL_DISORDER);
-        $self->register_event("THE GOVERNMENT WON THE CIVIL WAR");
+        $world->broadcast_event( { code => 'govwincivil',
+                                   text => "THE GOVERNMENT OF " . $self->name . " WON THE CIVIL WAR",
+                                   involved => [$self->name] }, $self->name );
         return 'government';
     }
     elsif($self->rebel_provinces == PRODUCTION_UNITS->[$self->size])
     {
         $self->internal_disorder(AFTER_CIVIL_WAR_INTERNAL_DISORDER);
-        $self->register_event("THE REBELS WON THE CIVIL WAR");
+        $world->broadcast_event( { code => 'rebwincivil',
+                                   text => "THE REBELS IN " . $self->name . " WON THE CIVIL WAR",
+                                   involved => [$self->name] }, $self->name );
+      
         $self->rebel_provinces(0);
         return 'rebels';
     }
@@ -434,7 +442,10 @@ sub win_civil_war
             $world->stop_rebel_military_support($rebel_supporter, $self) if $rebel_supporter;
             $world->diplomacy_exists($self->name, $rebel_supporter->name)->factor(REBEL_SUPPORTER_WINNER_FRIENDSHIP);
             $world->create_treaty($self->name, $rebel_supporter->name, 'alliance');
-            $world->broadcast_event($self->name . " AND " . $rebel_supporter->name . " ARE NOW ALLIES. " . $rebel_supporter->name . " HELPED " . $self->name . " REVOLUTION", $self->name, $rebel_supporter->name);
+            $world->broadcast_event({ code => 'alliancetreatynew',
+                                     text => "ALLIANCE BETWEEN " . $self->name . " AND " . $rebel_supporter->name, 
+                                     involved => [$self->name, $rebel_supporter->name],
+                                     values => ['rebsup'] }, $self->name, $rebel_supporter->name);
         }
         $world->empty_stocks($self->name);
         $self->available_stocks(START_STOCKS->[$self->size]);
@@ -460,7 +471,9 @@ sub new_government
     $world->reset_influences($self->name);
     $world->reset_supports($self->name);
     $world->reset_crises($self->name);
-    $self->register_event("NEW GOVERNMENT CREATED");
+    $world->broadcast_event({ code => "newgov",
+                              text => "NEW GOVERNMENT CREATED IN " . $self->name,
+                              involved => [$self->name] }, $self->name);
 }
 
 sub occupation
