@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Diplomat;
-$BalanceOfPower::Role::Diplomat::VERSION = '0.300012';
+$BalanceOfPower::Role::Diplomat::VERSION = '0.300020';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -196,20 +196,56 @@ sub change_diplomacy
     my $node1 = shift;
     my $node2 = shift;
     my $dipl = shift;
+    my $reason = shift;
     my $r = $self->diplomacy_exists($node1, $node2);
     return if(!$r ); #Should never happen
     return if $r->status eq 'ALLIANCE' || $r->status eq 'INFLUENCE PRESENT';
     my $present_status = $r->status;
     $r->change_factor($dipl);
     my $actual_status = $r->status;
+    my $trend = $dipl > 0 ? 'up' : 'down';
     if($present_status ne $actual_status)
     {
-        $self->broadcast_event("RELATION BETWEEN $node1 AND $node2 CHANGED FROM $present_status TO $actual_status", $node1, $node2);
+        my $event_text = "RELATIONS BETWEEN $node1 AND $node2 CHANGED FROM $present_status TO $actual_status";
+        if($reason)
+        {
+            $event_text = $event_text . " " . $reason;
+        }
+        else
+        {
+            $reason = "";
+        }
+        $self->broadcast_event({ code => "relchange",
+                                 text => $event_text,
+                                 involved => [$node1, $node2],
+                                 values => [$trend, $present_status, $actual_status, $reason]},
+                                $node1, $node2);
         if($actual_status eq 'HATE')
         {
             $self->diplomatic_breakdown($node1, $node2);
         }
     }
+    else
+    {
+        my $event_text;
+        if($dipl > 0)
+        {
+            $event_text = "RELATIONS BETWEEN $node1 AND $node2 ARE BETTER";
+        }
+        else
+        {
+            $event_text = "RELATIONS BETWEEN $node1 AND $node2 ARE WORSE";
+        }
+        if($reason)
+        {
+            $event_text = $event_text . " " . $reason;
+        }
+        $self->broadcast_event({ code => "relchange",
+                                 text => $event_text,
+                                 involved => [$node1, $node2],
+                                 values => [$trend, $actual_status, $actual_status, $reason]},
+                                $node1, $node2);
+    }
 }
 sub diplomacy_status
 {
@@ -228,7 +264,11 @@ sub diplomatic_breakdown
     my $treaty = $self->exists_treaty($n1, $n2);
     if($treaty)
     {
-        $self->broadcast_event($treaty->short_tag . " TREATY BETWEEN $n1 AND $n2 BROKEN", $n1, $n2);
+        $self->delete_treaty($n1, $n2);
+        $self->broadcast_event({ code => lc($treaty->short_tag) . "treatybroken",
+                                 text => $treaty->short_tag . " TREATY BETWEEN $n1 AND $n2 BROKEN",
+                                 involved => [$n1, $n2] },
+                                 $n1, $n2);
     }
     $self->stop_military_support($self->get_nation($n1), $self->get_nation($n2), 1);
     $self->stop_military_support($self->get_nation($n2), $self->get_nation($n1), 1);
@@ -271,12 +311,14 @@ sub diplomatic_pressure
     my $nation1 = shift;
     my $nation2 = shift;
     my @friends = $self->get_friends($nation1);
-    $self->change_diplomacy($nation1, $nation2, DIPLOMATIC_PRESSURE_FACTOR);
-    $self->broadcast_event("DIPLOMATIC PRESSURE OF $nation1 ON $nation2", $nation1, $nation2);
+    $self->change_diplomacy($nation1, $nation2, DIPLOMATIC_PRESSURE_FACTOR, "DIPLOMATIC PRESSURE OF $nation1 ON $nation2");
+    $self->broadcast_event({ code => 'pressure',
+                             text => "DIPLOMATIC PRESSURE OF $nation1 ON $nation2",
+                             involved =>  [$nation1, $nation2] }, $nation1, $nation2);
     for(@friends)
     {
         my $f = $_;
-        $self->change_diplomacy($f, $nation2, DIPLOMATIC_PRESSURE_FACTOR);
+        $self->change_diplomacy($f, $nation2, DIPLOMATIC_PRESSURE_FACTOR, "DIPLOMATIC PRESSURE OF $nation1 ON $nation2");
     }
 }
 
