@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Historian;
-$BalanceOfPower::Role::Historian::VERSION = '0.300012';
+$BalanceOfPower::Role::Historian::VERSION = '0.300020';
 use v5.10;
 use strict;
 use Moo::Role;
@@ -19,6 +19,7 @@ has statistics => (
 );
 
 requires 'get_nation';
+requires 'by_tags';
 
 sub get_statistics_value
 {
@@ -237,7 +238,7 @@ sub print_nation_events
     my $title = shift;
     my $mode = shift || 'print';
     my $nation = $self->get_nation($nation_name);
-    return $nation->print_turn_events($y, $title, 0, $mode);
+    return $nation->print_turn_events($y, $title, 3, $mode);
 }
 
 sub print_turn_statistics
@@ -355,6 +356,78 @@ sub print_defcon_statistics
     return $out;
 }
 
+sub print_newspaper
+{
+    my $self = shift;
+    my $y = shift;
+    my $title = shift;
+    my $mode = shift || 'print';
+    return "" if(! exists $self->events->{$y});
+    my @ignored = ('traderefused', 'tradelack', 'wargoon', 'pressure', 'crisisstart', 'crisisup', 'crisisdown', 'crisisend', 'supfailed', 'rebsupfailed', 'progress', 'hatetreaty', 'limittreaty', 'uselesstreaty', 'lowerdisorder', 'disorderchange', 'acquireprogress', 'occupy', 'domintate', 'control', 'crisisescalate', 'nopartecipatewar', 
+ );
+    my @managed = ('bestprogress', 'bestwealth', 'tradedeleted', 'tradeadded', 'relchange', 'militaryaid', 'insurgentsaid', 'economicaid', 'supincreased', 'supstarted', 'supstopped', 'supdestroyed', 'suprefused', 'rebsupincreased', 'rebsupstarted','rebsupstopped', 'comtreatynew', 'nagtreatynew', 'alliancetreatynew', 'comtreatybroken', 'nagtreatybroken', 'alltreatybroken', 'govwincivil', 'rebwincivil', 'civiloutbreak' );
+    my @war_events = ('warstart', 'warlinkedstart', 'warend');
+    my @generic = ();
+    my %events = $self->by_tags(@{$self->events->{$y}});
+    my %wars = ();
+    foreach my $key (keys %events)
+    {
+        if(grep { $_ eq $key } @ignored)
+        {
+            delete $events{$key};
+        }
+        elsif(grep { $_ eq $key } @managed)
+        {
+            #No action needed
+        }
+        elsif(grep { $_ eq $key } @war_events)
+        {
+            foreach my $e (@{$events{$key}})
+            {
+                my $war_id = $e->{values}->[0];
+                if($key eq 'warstart')
+                {
+                    $wars{$war_id}->{'warstart'} = $e;
+                }
+                elsif($key eq 'warlinkedstart')
+                {
+                    if(exists $wars{$war_id} && exists $wars{$war_id}->{'warlinkedstart'})
+                    {
+                        push @{ $wars{$war_id}->{'warlinkedstart'} }, $e;
+                    }
+                    else
+                    {
+                        $wars{$war_id}->{'warlinkedstart'} = [ $e ];
+                    }
+                }
+                elsif($key eq 'warend')
+                {
+                    if(exists $wars{$war_id} && exists $wars{$war_id}->{'warend'})
+                    {
+                        push @{ $wars{$war_id}->{'warend'} }, $e;
+                    }
+                    else
+                    {
+                        $wars{$war_id}->{'warend'} = [ $e ];
+                    }
+                    
+                }
+            }
+        
+        }
+        else
+        {
+            @generic = (@generic, @{$events{$key}});
+        }
+    }
+    $events{'others'} = \@generic;
+    $events{'wars'} = \%wars;
+    return BalanceOfPower::Printer::print($mode, $self, 'print_newspaper', 
+                                   { title => $title,
+                                     turn => $y,
+                                     events => \%events });
+}
+
 sub dump_statistics
 {
     my $self = shift;
