@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Merchant;
-$BalanceOfPower::Role::Merchant::VERSION = '0.300012';
+$BalanceOfPower::Role::Merchant::VERSION = '0.300020';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -95,8 +95,11 @@ sub generate_traderoute
     {
         $n1->subtract_production('export', ADDING_TRADEROUTE_COST);
         $n2->subtract_production('export', ADDING_TRADEROUTE_COST);
-        $self->change_diplomacy($node1, $node2, TRADEROUTE_DIPLOMACY_FACTOR);
-        my $event = "TRADEROUTE ADDED: $node1<->$node2";
+        $self->change_diplomacy($node1, $node2, TRADEROUTE_DIPLOMACY_FACTOR, "TRADE CREATION");
+        my $event = { code => 'tradeadded',
+                      text => "TRADEROUTE ADDED: $node1<->$node2",
+                      involved => [$node1, $node2],
+                      values => [] };
         $self->broadcast_event($event, $node1, $node2);
     }
                
@@ -117,9 +120,12 @@ sub delete_route
     else
     {
         $self->delete_traderoute($node1, $node2);
-        my $event = "TRADEROUTE DELETED: $node1<->$node2";
+        my $event = { code => 'tradedeleted',
+                      text => "TRADEROUTE DELETED: $node1<->$node2",
+                      involved => [$node1, $node2],
+                      values => [] };
         $self->broadcast_event($event, $node1, $node2);
-        $self->change_diplomacy($node1, $node2, -1 * TRADEROUTE_DIPLOMACY_FACTOR);
+        $self->change_diplomacy($node1, $node2, -1 * TRADEROUTE_DIPLOMACY_FACTOR, "TRADE DELETION");
     }
 }
 sub suitable_route_creator
@@ -145,7 +151,9 @@ sub suitable_new_route
     }
     else
     {
-        $self->broadcast_event($node1->name . " AND " . $node2->name . " REFUSED TO OPEN A TRADEROUTE", $node1->name, $node2->name);
+        $self->broadcast_event({ code => 'traderefused',
+                                 text => $node1->name . " AND " . $node2->name . " REFUSED TO OPEN A TRADEROUTE", 
+                                 involved => [$node1->name, $node2->name] }, $node1->name, $node2->name);
         return 0;
     }
 }
