@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::WebMaster;
-$BalanceOfPower::Role::WebMaster::VERSION = '0.300012';
+$BalanceOfPower::Role::WebMaster::VERSION = '0.300020';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -88,6 +88,9 @@ sub build_post_statics
     open(my $events, "> $dest_dir/events.tt"); 
     print {$events} $self->print_formatted_turn_events($year, undef, 'html');  
     close($events);
+    open(my $news, "> $dest_dir/newspaper.tt"); 
+    print {$news} $self->print_newspaper($year, "News", 'html');  
+    close($news);
 }
 
 sub build_meta_statics
@@ -116,7 +119,7 @@ sub build_nations_statics
     my $self = shift;
     my $game = shift;
     my $site_root = $self->site_root;
-    foreach my $code (keys $self->nation_codes)
+    foreach my $code (keys %{$self->nation_codes})
     {
         my $nation = $self->nation_codes->{$code};
 
