@@ -1,5 +1,5 @@
 package BalanceOfPower::World;
-$BalanceOfPower::World::VERSION = '0.300012';
+$BalanceOfPower::World::VERSION = '0.300020';
 use strict;
 use v5.10;
 
@@ -469,7 +469,11 @@ sub calculate_prestige
             if($ordered_best_w[$i]->{nation} eq $nation_name)
             {
                 $bonus += BEST_WEALTH_FOR_PRESTIGE_BONUS;
-                $self->broadcast_event("ONE OF THE FIRST " . BEST_WEALTH_FOR_PRESTIGE . " NATIONS FOR WEALTH WAS " . $nation_name, $nation_name);
+                $self->broadcast_event({ code => 'bestwealth',
+                                         text => "ONE OF THE FIRST " . BEST_WEALTH_FOR_PRESTIGE . " NATIONS FOR WEALTH WAS " . $nation_name, 
+                                         involved => [ $nation_name ],
+                                         values => [] },
+                                        $nation_name);
             }
         }
     }
@@ -481,7 +485,11 @@ sub calculate_prestige
             if($ordered_best_p[$i]->{nation} eq $nation_name)
             {
                 $bonus += BEST_PROGRESS_FOR_PRESTIGE_BONUS;
-                $self->broadcast_event("ONE OF THE FIRST " . BEST_PROGRESS_FOR_PRESTIGE . " NATIONS FOR PROGRESS WAS " . $nation_name, $nation_name);
+                $self->broadcast_event({ code => 'bestprogress',
+                                         text => "ONE OF THE FIRST " . BEST_PROGRESS_FOR_PRESTIGE . " NATIONS FOR PROGRESS WAS " . $nation_name, 
+                                         involved => [$nation_name],
+                                         values => [] },
+                                        $nation_name);
             }
         }
     }
@@ -561,7 +569,9 @@ sub execute_decisions
             }
             else
             {
-                $self->broadcast_event($supported->name . " REFUSED MILITARY SUPPORT FROM " . $supporter->name);
+                $self->broadcast_event({ code => 'suprefused',
+                                         text => $supported->name . " REFUSED MILITARY SUPPORT FROM " . $supporter->name,
+                                         involved => [$supporter->name, $supported->name] }, $supporter->name, $supported->name);
             }
         }
         elsif($command =~ /^RECALL MILITARY SUPPORT (.*)$/)
@@ -589,14 +599,7 @@ sub execute_decisions
         {
             my $nation2 = $self->get_nation($1);
             my $rebsup = $self->rebel_supported($nation2->name);
-            if($rebsup && $rebsup->node1 ne $nation->name)
-            {
-                $self->broadcast_event("REBEL SUPPORT IN " . $nation2->name . " IMPOSSIBLE FOR " . $nation->name, $nation->name, $nation2->name);
-            }
-            else
-            {
-                $self->start_rebel_military_support($nation, $nation2);
-            }
+            $self->start_rebel_military_support($nation, $nation2);
         }
         elsif($command =~ /^DIPLOMATIC PRESSURE ON (.*)$/)
         {
@@ -628,7 +631,9 @@ sub execute_decisions
         elsif($command =~ /^PROGRESS$/)
         {
             $nation->grow();
-            $self->broadcast_event("INVESTMENT IN PROGRESS FOR " . $nation->name, $nation->name);
+            $self->broadcast_event({ code => 'progress',
+                                     text => "INVESTMENT IN PROGRESS FOR " . $nation->name, 
+                                     involved => [$nation->name] }, $nation->name);
         }
         $self->set_statistics_value($nation, 'order', $command);
     }
@@ -659,7 +664,9 @@ sub manage_route_adding
             {
                 if(@route_adders == 0)
                 {
-                    $self->send_event("TRADEROUTE CREATION FAILED FOR LACK OF PARTNERS", $node1);
+                    $self->broadcast_event( { code => "tradelack",
+                                              text => "TRADEROUTE CREATION FAILED FOR LACK OF PARTNERS FOR $node1", 
+                                              involved => [$node1] }, $node1);
                     $done = 1;
                 } 
                 else
@@ -677,7 +684,9 @@ sub manage_route_adding
                     }     
                     if($complete == 0)
                     {
-                        $self->send_event("TRADEROUTE CREATION FAILED FOR LACK OF PARTNERS", $node1);
+                        $self->broadcast_event( { code => "tradelack",
+                                                  text => "TRADEROUTE CREATION FAILED FOR LACK OF PARTNERS FOR $node1", 
+                                                  involved => [$node1] }, $node1);
                     }
                 }
             }
@@ -796,8 +805,10 @@ sub economic_aid
     my $nation2 = shift;
     $nation1->subtract_production('export', ECONOMIC_AID_COST);
     $nation2->receive_aid($nation1->name);
-    $self->broadcast_event("ECONOMIC AID FROM " . $nation1->name . " TO " . $nation2->name, $nation1->name, $nation2->name);
-    $self->change_diplomacy($nation1->name, $nation2->name, ECONOMIC_AID_DIPLOMACY_FACTOR);
+    $self->broadcast_event({ code => 'economicaid' , 
+                             text => "ECONOMIC AID FROM " . $nation1->name . " TO " . $nation2->name, 
+                             involved => [$nation1->name, $nation2->name] }, $nation1->name, $nation2->name);
+    $self->change_diplomacy($nation1->name, $nation2->name, ECONOMIC_AID_DIPLOMACY_FACTOR, "ECONOMIC AID FROM " . $nation1->name);
 
 }
 
@@ -836,7 +847,10 @@ sub aid_insurgents
     my $nation2 = shift;
     if($nation1->production_for_export >= AID_INSURGENTS_COST && $nation2->internal_disorder_status ne 'Civil war')
     {
-        $self->broadcast_event("AIDS FOR INSURGENTS OF " . $nation2->name . " FROM " . $nation1->name, $nation1->name, $nation2->name);
+        $self->broadcast_event({ code => 'insurgentsaid' ,
+                                 text => "AIDS FOR INSURGENTS OF " . $nation2->name . " FROM " . $nation1->name, 
+                                 involved => [$nation1->name, $nation2->name] },
+                                $nation1->name, $nation2->name);
         $nation1->subtract_production('export', AID_INSURGENTS_COST);
         $nation2->add_internal_disorder(INSURGENTS_AID, $self);
     }
@@ -854,7 +868,9 @@ sub start_civil_war
 {
     my $self = shift;
     my $nation = shift;
-    $self->broadcast_event("CIVIL WAR OUTBREAK IN " . $nation->name, $nation->name);
+    $self->broadcast_event({ code => "civiloutbreak",
+                             text => "CIVIL WAR OUTBREAK IN " . $nation->name, 
+                             involved => [$nation->name] }, $nation->name);
     $nation->rebel_provinces(STARTING_REBEL_PROVINCES->[$nation->size]);
     $self->war_report("Civil war in " . $nation->name . "!", $nation->name);
     $self->lose_war($nation->name, 1);
@@ -881,8 +897,10 @@ sub military_aid
     my $nation2 = shift;
     $nation1->subtract_production('export', MILITARY_AID_COST);
     $nation2->add_army(ARMY_UNIT);
-    $self->broadcast_event("MILITARY AID FROM " . $nation1->name . " TO " . $nation2->name, $nation1->name, $nation2->name);
-    $self->change_diplomacy($nation1->name, $nation2->name, MILITARY_AID_DIPLOMACY_FACTOR);
+    $self->broadcast_event({ code => 'militaryaid',
+                             text => "MILITARY AID FROM " . $nation1->name . " TO " . $nation2->name,
+                             involved => [$nation1->name, $nation2->name] }, $nation1->name, $nation2->name);
+    $self->change_diplomacy($nation1->name, $nation2->name, MILITARY_AID_DIPLOMACY_FACTOR, "MILITARY AID FROM " . $nation1->name );
 }
 
 sub war_report
@@ -912,51 +930,59 @@ sub stipulate_treaty
     my $diplomatic_status = $self->diplomacy_status($nation1->name, $nation2->name);
     if($diplomatic_status eq 'HATE')
     {
-        $self->broadcast_event("TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name . " NOT POSSIBLE BECAUSE OF HATE", $nation1->name, $nation2->name);
+        $self->broadcast_event({ code => 'hatetreaty',
+                                 text => "TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name . " NOT POSSIBLE BECAUSE OF HATE", 
+                                 involved => [$nation1->name, $nation2->name] }, $nation1->name, $nation2->name);
         return;
     }
     if($self->get_treaties_for_nation($nation1->name) >= $nation1->treaty_limit ||
-       $self->get_treaties_for_nation($nation2->name) >= $nation2->treaty_limit)
+       $self->get_treaties_for_nation($nation2->name) >= $nation2->treaty_limit &&
+       ! $present_treaty)
     {
-        $self->broadcast_event("TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name . " NOT POSSIBLE BECAUSE ONE NATION HAS ALREADY REACHED MAXIMUM ALLOWED TREATIES", $nation1->name, $nation2->name);
+        $self->broadcast_event( { code => 'limittreaty',
+                                  text => "TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name . " NOT POSSIBLE BECAUSE ONE NATION HAS ALREADY REACHED MAXIMUM ALLOWED TREATIES", 
+                                  involved => [$nation1->name, $nation2->name] }, $nation1->name, $nation2->name);
         return;
     }
     if($nation1->prestige >= TREATY_PRESTIGE_COST)
     {
-        if($type eq 'COM')
+        if($present_treaty && $present_treaty->type ne 'alliance')
         {
-            if(! $present_treaty)
-            {
-                if($self->route_exists($nation1->name, $nation2->name))
-                {
-                    $self->create_treaty($nation1->name, $nation2->name, 'commercial');
-                    $self->broadcast_event("COMMERCIAL TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name, $nation1->name, $nation2->name);
-                }
-                else
-                {
-                    $self->broadcast_event("COMMERCIAL TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name . " MADE USELESS BY ROUTE CANCELATION", $nation1->name, $nation2->name);
-                }
-            }
-        }
-        elsif($type eq 'NAG')
-        {
-            if(! $present_treaty)
-            {
-                $self->create_treaty($nation1->name, $nation2->name, 'no aggression');
-                $self->broadcast_event("NO AGGRESSION TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name, $nation1->name, $nation2->name);
-            }
+            $self->create_treaty($nation1->name, $nation2->name, 'alliance');
+            $self->broadcast_event({ code => 'alliancetreatynew',
+                                     text => "ALLIANCE BETWEEN " . $nation1->name . " AND " . $nation2->name, 
+                                     involved => [$nation1->name, $nation2->name] }, $nation1->name, $nation2->name);
         }
         else
         {
-            if($present_treaty && $present_treaty->type ne 'alliance')
+            if($type eq 'COM')
             {
-                $self->create_treaty($nation1->name, $nation2->name, 'alliance');
-                $self->broadcast_event("ALLIANCE BETWEEN " . $nation1->name . " AND " . $nation2->name, $nation1->name, $nation2->name);
+                if(! $present_treaty)
+                {
+                    if($self->route_exists($nation1->name, $nation2->name))
+                    {
+                        $self->create_treaty($nation1->name, $nation2->name, 'commercial');
+                        $self->broadcast_event({ code => "comtreatynew",
+                                                text => "COMMERCIAL TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name, 
+                                                involved => [$nation1->name, $nation2->name] }, $nation1->name, $nation2->name);
+                    }
+                    else
+                    {
+                        $self->broadcast_event({ code => "uselesstreaty",
+                                                text => "COMMERCIAL TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name . " MADE USELESS BY ROUTE CANCELATION", 
+                                                involved => [$nation1->name, $nation2->name] }, $nation1->name, $nation2->name);
+                    }
+                }
+            }
+            elsif($type eq 'NAG')
+            {
+                $self->create_treaty($nation1->name, $nation2->name, 'no aggression');
+                $self->broadcast_event({ code => 'nagtreatynew',
+                                         text => "NO AGGRESSION TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name, 
+                                         involved => [$nation1->name, $nation2->name] }, $nation1->name, $nation2->name);
             }
         }
     }
-
-
 }
 
 
@@ -974,24 +1000,9 @@ sub register_global_data
 
 sub collect_events
 {
-    my $self = shift;
-    my @events_to_collect = ("DISORDER LOWERED TO",
-                             "INTERNAL DISORDER LEVEL FROM",
-                             "THE GOVERNMENT WON THE CIVIL WAR",
-                             "THE REBELS WON THE CIVIL WAR",
-                             "NEW GOVERNMENT CREATED",
-                             "TRADEROUTE CREATION FAILED FOR LACK OF PARTNERS");
+   my $self = shift;
    foreach my $n (@{$self->nations})
    {
-       my @collected = ();
-       foreach my $e (@events_to_collect)
-       {
-            push @collected, $n->get_events($e, $self->current_year);
-       }
-       foreach my $c (@collected)
-       {
-            $self->register_event($n->name . ": ". $c);
-       }
        $self->set_statistics_value($n, 'progress', $n->progress);
    }
 }
